
// Aqui estamos importando o módulo Express, que é um framework web para Node.js que facilita a criação de aplicações web.
const express = require('express');

// Multer é um middleware para lidar com multipart/form-data, que é usado para o upload de arquivos.
const multer  = require('multer');

//O módulo path fornece utilitários para trabalhar com caminhos de arquivos e diretórios.
const path    = require('path');

// Array dos uploads
let uploadedFiles = [];


const app = express();
// Como devemos configurar a porta para funcionar na Integrator Host
const port = process.env.PORT //aqui será a porta que o PM2 irá colocar
//const port = 3000;

// Configuração do Multer (você pode alterar o destino ou os nomes dos arquivos aqui)
const storage = multer.diskStorage({
    
    // Destination: Define o diretório onde os arquivos serão salvos.
    destination: (req, file, cb) => {
        cb(null, 'uploads/');
    },

    // filename: Define o nome do arquivo. No nosso caso, estamos nomeando o arquivo com o timestamp atual (para evitar sobreposições) e a extensão original do arquivo.
    filename: (req, file, cb) => {
        cb(null, Date.now() + path.extname(file.originalname));
    }
});

// Aqui, estamos inicializando o middleware Multer com a configuração de armazenamento definida anteriormente.
const upload = multer({ storage: storage });

// Rota para o formulário de upload
app.get('/', (req, res) => {
    console.log("ROTA recebida para / RAIZ do seu Domínio");
    res.sendFile(path.join(__dirname, 'index.html'));
});

// Rota para lidar com o upload
app.post('/upload', upload.single('sampleFile'), (req, res) => {
    if (!req.file) {
        return res.send('Por favor, selecione um arquivo para fazer upload.');
    }
    uploadedFiles.push(req.file.filename);
    res.send('Arquivo enviado com sucesso!');
});

// Rota para listar os uploads realizados
const fs = require('fs');
app.get('/listar', (req, res) => {
    fs.readdir(path.join(__dirname, 'uploads'), (err, files) => {
        if (err) {
            return res.status(500).send('Erro ao listar os arquivos.');
        }
        res.json(files);
    });
});

// execução do app
app.listen(port, function(){  
    console.info(`Server running in the port ${port}`);
});
